========
Euphonic
========

Euphonic is a Python package that can efficiently calculate phonon
bandstructures and inelastic neutron scattering intensities from a
force constants matrix (e.g. from a .castep_bin file). While Euphonic
is primarily a library, a command-line tool is provided for convenient
plotting of inelastic neutron scattering intensities from
force-constants data.

Euphonic can also plot previously-calculated dispersion and density of
states data from a CASTEP .phonon file.

For more information, see the `docs <http://euphonic.readthedocs.io/en/latest/>`_.
